==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PrzelewDruk.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class PrzelewDruk extends GenericDPSObject {
    /**
     * PRZELEW_DRUK.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * PRZELEW_DRUK.DATA_GENEROWANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataGenerowania;

    /**
     * PRZELEW_DRUK.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * PRZELEW_DRUK.TYTULEM
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String tytulem;

    /**
     * PRZELEW_DRUK.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zadluzeniePozycjaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PRZELEW_DRUK.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PRZELEW_DRUK.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PRZELEW_DRUK.DATA_GENEROWANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataGenerowania() {
        return dataGenerowania;
    }

    /**
     * PRZELEW_DRUK.DATA_GENEROWANIA
     *
     * @param dataGenerowania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataGenerowania(Date dataGenerowania) {
        this.dataGenerowania = dataGenerowania;
    }

    /**
     * @return PRZELEW_DRUK.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * PRZELEW_DRUK.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return PRZELEW_DRUK.TYTULEM
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getTytulem() {
        return tytulem;
    }

    /**
     * PRZELEW_DRUK.TYTULEM
     *
     * @param tytulem
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTytulem(String tytulem) {
        this.tytulem = tytulem == null ? null : tytulem.trim();
    }

    /**
     * @return PRZELEW_DRUK.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * PRZELEW_DRUK.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PrzelewDruk other = (PrzelewDruk) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDataGenerowania() == null ? other.getDataGenerowania() == null : this.getDataGenerowania().equals(other.getDataGenerowania()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getTytulem() == null ? other.getTytulem() == null : this.getTytulem().equals(other.getTytulem()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDataGenerowania() == null) ? 0 : getDataGenerowania().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getTytulem() == null) ? 0 : getTytulem().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dataGenerowania=").append(dataGenerowania);
        sb.append(", kwota=").append(kwota);
        sb.append(", tytulem=").append(tytulem);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PrzelewDruk.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class PrzelewDruk extends GenericDPSObject {
    /**
     * PRZELEW_DRUK.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * PRZELEW_DRUK.DATA_GENEROWANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataGenerowania;

    /**
     * PRZELEW_DRUK.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * PRZELEW_DRUK.TYTULEM
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String tytulem;

    /**
     * PRZELEW_DRUK.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zadluzeniePozycjaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PRZELEW_DRUK.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PRZELEW_DRUK.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PRZELEW_DRUK.DATA_GENEROWANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataGenerowania() {
        return dataGenerowania;
    }

    /**
     * PRZELEW_DRUK.DATA_GENEROWANIA
     *
     * @param dataGenerowania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataGenerowania(Date dataGenerowania) {
        this.dataGenerowania = dataGenerowania;
    }

    /**
     * @return PRZELEW_DRUK.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * PRZELEW_DRUK.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return PRZELEW_DRUK.TYTULEM
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getTytulem() {
        return tytulem;
    }

    /**
     * PRZELEW_DRUK.TYTULEM
     *
     * @param tytulem
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTytulem(String tytulem) {
        this.tytulem = tytulem == null ? null : tytulem.trim();
    }

    /**
     * @return PRZELEW_DRUK.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * PRZELEW_DRUK.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PrzelewDruk other = (PrzelewDruk) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDataGenerowania() == null ? other.getDataGenerowania() == null : this.getDataGenerowania().equals(other.getDataGenerowania()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getTytulem() == null ? other.getTytulem() == null : this.getTytulem().equals(other.getTytulem()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDataGenerowania() == null) ? 0 : getDataGenerowania().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getTytulem() == null) ? 0 : getTytulem().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dataGenerowania=").append(dataGenerowania);
        sb.append(", kwota=").append(kwota);
        sb.append(", tytulem=").append(tytulem);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append("]");
        return sb.toString();
    }
}
